@@ -13,7 +13,7 @@ from ...consts import (
     LOGS,
     SERVICE_CODE
     )
-# from ...code_error import CODE_ERROR
+from ...code_error import CODE_ERROR
 from . import api
 from ...ocs import get_language, send_sms, get_balance, update_balance
 from ...sms import MESSAGE
@@ -175,35 +175,76 @@ def smsCustomerRegister():
                 ]
                 )
             )
-    data["data"]["data"]["contacts"] = [
-        {
-            "viewers_contact_type": "Mobile",
-            "viewers_contact_content": data["data"]["data"].get(["phone"])
-            },
-        {
-            "viewers_contact_type": "Email",
-            "viewers_contact_content": data["data"]["data"].get(["mail"])
-            }
-        ]
-    del(data["data"]["data"]["phone"])
-    del(data["data"]["data"]["mail"])
+    if (
+            data["data"]["data"].get("viewers_telephone") and
+            data["data"]["data"].get("viewers_mail")
+            ):
+        data["data"]["data"]["contacts"] = [
+            {
+                "viewers_contact_type": "Mobile",
+                "viewers_contact_content": data["data"]["data"].get(
+                    "viewers_telephone"
+                    )
+                },
+            {
+                "viewers_contact_type": "Email",
+                "viewers_contact_content": data["data"]["data"].get(
+                    "viewers_mail"
+                    )
+                }
+            ]
+        del(data["data"]["data"]["viewers_telephone"])
+        del(data["data"]["data"]["viewers_mail"])
 
-    data["data"]["data"]["addresses"] = [
-        {
-            "viewers_address_type": "Customer address",
-            "viewers_address_address": data["data"]["data"].get(["rue"]),
-            "viewers_address_streetname": data["data"]["data"].get(["rue"]),
-            "viewers_address_city": data["data"]["data"].get(["ville"]),
-        },
-        ]
-    del(data["data"]["data"]["rue"])
-    del(data["data"]["data"]["ville"])
+    if (
+            data["data"]["data"].get("viewers_adresse_rue") and
+            data["data"]["data"].get("viewers_adresse_ville")
+            ):
+        data["data"]["data"]["addresses"] = [
+            {
+                "viewers_address_type": "Customer address",
+                "viewers_address_streetname": data["data"]["data"].get(
+                    "viewers_adresse_rue"
+                    ),
+                "viewers_address_city": data["data"]["data"].get(
+                    "viewers_adresse_ville"
+                    ),
+            },
+            ]
+        del(data["data"]["data"]["viewers_adresse_rue"])
+        del(data["data"]["data"]["viewers_adresse_ville"])
     data = json.dumps(data)
+    LOGS.logger.info(data)
     response = requests.post(
         '{uri}/customer/update'.format(uri=SMS_URI),
         data=data
         )
-    response = response.json()
+    if response.status_code == 200:
+        status_code = 200
+        response = response.json()
+        if response["status"] == 1:
+            status_code = 1
+            info = "IzyTv customer register successfully ;)"
+            data = response["response"]
+        else:
+            status_code = response["status"]
+            info = "IzyTv customer register {error}".format(
+                    error=(CODE_ERROR.get(str(response["status"]))).lower()
+                    )
+            data = {}
+    else:
+        status_code = response.status_code
+        info = "IzyTv customer register failed!!!"
+        data = {}
+
+    response = {
+        "code": "044-05-{}".format(status_code),
+        "info": info,
+        "response": data,
+        "status": status_code,
+        }
+    LOGS.logger.info(response)
+
     return jsonify(response)
 
 
@@ -272,7 +313,7 @@ def smsCustomerSaveInvoice():
             LOGS.logger.info(response)
             response = {
                 "invoices": response["response"]["invoices"],
-                "status": response["status"]
+                "status": 1
                 }
             LOGS.logger.info("Activation successful")
             LOGS.logger.info(response)
@@ -326,17 +367,27 @@ def ussdCustomerGetDataByLogin():
     if response.status_code == 200:
         response = response.json()
         if response["status"] == 1:
+            customer = Customer()
+            result = customer.getData(int(
+                response["response"]["device_motv_viewers_id"])
+                )
+            if result["status"] == 1:
+                customer_name = (
+                    result["response"]["viewers_firstname"] +
+                    " " +
+                    result["response"]["viewers_lastname"]
+                    )
+            else:
+                customer_name = response["response"]["device_motv_login"]
             response = {
                 "code": "044-05-200",
                 "message": {
-                    "customer_name": (
-                        response["response"]["device_motv_login"]
-                        ),
+                    "customer_name": customer_name,
                     "customer_id": (
                         response["response"]["device_motv_viewers_id"]
                         ),
                     },
-                "status": 200,
+                "status": 1,
                 }
             LOGS.logger.info(response)
         elif response["status"] == 14001:
@@ -548,6 +599,17 @@ def subscriptionInfo(login):
                     code=4016
                     )
                 )
+        elif response["status"] == 721:
+            LOGS.logger.info("Pas de recharge en cours")
+            LOGS.logger.info(response)
+            response = {
+                "code": "044-05-200",
+                "message": {"subscriptions": [
+                    {"name": "Pas de recharge en cours", "value": 0}
+                    ]},
+                "status": 200,
+            }
+
     else:
         response = customer
         return bad_request(
@@ -570,6 +632,8 @@ def ussdCustomerSaveInvoice(login):
     """
     params = request.get_json()
     auth = request.authorization
+    headers = request.headers
+    request_id = headers["X-Request-Id"]
 
     # get language
     language = get_language(
@@ -597,6 +661,7 @@ def ussdCustomerSaveInvoice(login):
                     auth.username,
                     "moins"
                     )
+                LOGS.logger.info("Account new: "+json.dumps(account_new))
                 if account_new["status"] == 200:
                     # Activation du produit
                     data = {
@@ -608,7 +673,7 @@ def ussdCustomerSaveInvoice(login):
                         "device_id": login,
                         "solde": params["amount"],
                         "offre_refnum": params["offer_id"],
-                        "partner_ref": "BIP"
+                        "partner_ref": request_id
                         }
                     LOGS.logger.info("Activation du produit")
                     LOGS.logger.info("data: "+json.dumps(data))
